'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CodeMirrorCore = undefined;

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _reactCodemirror = require('react-codemirror2');

var _materialUi = require('material-ui');

var _editorTypes = require('./editorTypes');

require('codemirror/lib/codemirror.css');

require('codemirror/mode/xml/xml');

require('codemirror/mode/sql/sql');

require('codemirror/mode/javascript/javascript');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var defaultOptions = {
  lineNumbers: true,
  lineWrapping: true
};

var CodeMirrorCore = function CodeMirrorCore(props) {
  var _props$input = props.input,
      value = _props$input.value,
      onChange = _props$input.onChange,
      _props$meta = props.meta,
      valid = _props$meta.valid,
      error = _props$meta.error,
      type = props.type,
      label = props.label,
      _props$defaultValue = props.defaultValue,
      defaultValue = _props$defaultValue === undefined ? '' : _props$defaultValue,
      required = props.required;
  var _editorTypes$type = _editorTypes.editorTypes[type],
      mode = _editorTypes$type.mode,
      format = _editorTypes$type.format,
      parse = _editorTypes$type.parse,
      toString = _editorTypes$type.toString;


  return _react2.default.createElement(
    'div',
    null,
    _react2.default.createElement(
      'span',
      { style: { color: '#c4c4c4' } },
      label,
      required ? ' * ' : ' '
    ),
    _react2.default.createElement(
      'span',
      { style: { color: '#ff3d3a' } },
      ' ',
      valid ? '' : '(' + error + ')'
    ),
    _react2.default.createElement(
      _materialUi.Toolbar,
      { noGutter: true },
      _react2.default.createElement(
        _materialUi.ToolbarGroup,
        null,
        _react2.default.createElement(_materialUi.FlatButton, { disabled: format === null, label: 'Format', onClick: function onClick() {
            return onChange(format(value));
          } })
      )
    ),
    _react2.default.createElement(_reactCodemirror.Controlled, {
      label: label,
      value: toString(value || defaultValue),
      options: (0, _extends3.default)({}, defaultOptions, { mode: mode }),
      onBeforeChange: function onBeforeChange(editor, data, valueFromEditor) {
        onChange(parse(valueFromEditor));
      }
    })
  );
};

CodeMirrorCore.propTypes = {
  input: _propTypes2.default.shape({
    value: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.array, _propTypes2.default.object]),
    onChange: _propTypes2.default.func
  }),
  meta: _propTypes2.default.shape({
    valid: _propTypes2.default.bool,
    error: _propTypes2.default.string
  }),
  source: _propTypes2.default.string,
  record: _propTypes2.default.object,
  type: _propTypes2.default.string.isRequired,
  label: _propTypes2.default.string,
  defaultValue: _propTypes2.default.string,
  required: _propTypes2.default.bool
};

exports.CodeMirrorCore = CodeMirrorCore;