'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.editorTypes = undefined;

var _sqlFormatter = require('sql-formatter');

var _sqlFormatter2 = _interopRequireDefault(_sqlFormatter);

var _pretty = require('pretty');

var _pretty2 = _interopRequireDefault(_pretty);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var editorTypes = exports.editorTypes = {
  sql: {
    mode: 'text/x-sql',
    format: function format(value) {
      return _sqlFormatter2.default.format(value);
    },
    parse: function parse(value) {
      return value;
    },
    toString: function toString(value) {
      return (value || '').toString();
    }
  },
  json: {
    mode: 'application/json',
    format: function format(value) {
      try {
        if (typeof value === 'string') {
          return JSON.stringify(JSON.parse(value), null, 2);
        }
        return JSON.stringify(value, null, 2);
      } catch (e) {
        return value;
      }
    },
    parse: function parse(value) {
      try {
        if (typeof value === 'string') return JSON.parse(value);
      } catch (e) {
        return value;
      }
    },
    toString: function toString(value) {
      if (value) {
        if (typeof value === 'string') return value;
        try {
          return JSON.stringify(value, null, 2);
        } catch (e) {
          return value;
        }
      }
      return '';
    }
  },
  html: {
    mode: 'text/html',
    format: function format(value) {
      return (0, _pretty2.default)(value);
    },
    parse: function parse(value) {
      return value;
    },
    toString: function toString(value) {
      return (value || '').toString();
    }
  }
};